@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2025 OARC, Inc.
+ * Copyright (c) 2018-2026 OARC, Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -35,6 +35,12 @@
 /*
  * Crypto-PAn encryption based on submitted extension by David Stott (Lucent)
  * https://www.cc.gatech.edu/computing/Networking/projects/cryptopan/lucent.shtml
+ *
+ * The original page has been lost but can be found on Internet Archive's Way Back Machine:
+ * https://web.archive.org/web/20180908092852/http://www.cc.gatech.edu/computing/Networking/projects/cryptopan/cpan-dts.tgz
+ *
+ * and a copy of the reference implementation in the directory cpan-dts
+ * together with this source code.
  */
 
 #include "config.h"
@@ -51,6 +57,7 @@
 #ifndef s6_addr32
 #define s6_addr32 __u6_addr.__u6_addr32
 #endif
+#include <endian.h>
 
 #include "dnscap_common.h"
 
@@ -322,12 +329,22 @@ static inline void _encrypt(uint32_t* in)
 
     memcpy(input.u.input, pad, 16);
     orig = ntohl(*in);
-    memcpy(&pad4b, pad, 4);
+    /*
+     * Consider first 4 bytes of padding as little endian byte order because
+     * reference implementation had specified:
+     *
+     *    first4bytes_pad = *(u_int32_t*)m_pad;
+     *
+     * which doesn't consider byte order and generates different results on
+     * big endian systems.
+     *
+     * One could argue that ntohl() should be used instead but that then
+     * breaks previous pseudo anonymized data.
+     */
+    pad4b = le32toh(input.u.ui32);
 
     // First pass with padding only
 
-    input.u.ui32 = htonl(pad4b);
-
     if (!EVP_CipherUpdate(ctx, output.u.outbuf, &outlen, input.u.input, 16)) {
         fprintf(stderr, "cryptopan.so: error encrypting: %s\n", ERR_reason_error_string(ERR_get_error()));
         exit(1);
@@ -370,12 +387,10 @@ static inline void _decrypt(uint32_t* in)
 
     memcpy(input.u.input, pad, 16);
     orig = ntohl(*in);
-    memcpy(&pad4b, pad, 4);
+    pad4b = le32toh(input.u.ui32); // see _encrypt() on why le32toh()
 
     // First pass with padding only
 
-    input.u.ui32 = htonl(pad4b);
-
     if (!EVP_CipherUpdate(ctx, output.u.outbuf, &outlen, input.u.input, 16)) {
         fprintf(stderr, "cryptopan.so: error encrypting: %s\n", ERR_reason_error_string(ERR_get_error()));
         exit(1);
