@@ -10,7 +10,6 @@
 #include <time.h>
 #include <stdarg.h>
 #include <errno.h>
-#include <assert.h>
 #include <sys/wait.h>
 
 #include <sys/types.h>
@@ -402,7 +401,7 @@ void rzkeychange_keytagsignal(const ldns_pkt* pkt, const ldns_rr* question_rr, i
         goto keytagsignal_done;
     key_tag_signals[num_key_tag_signals].addr   = addr;
     key_tag_signals[num_key_tag_signals].signal = strdup(qn_str);
-    assert(key_tag_signals[num_key_tag_signals].signal);
+    assert(key_tag_signals[num_key_tag_signals].signal != NULL);
     if (ldns_pkt_rd(pkt))
         key_tag_signals[num_key_tag_signals].flags |= KEYTAG_FLAG_RD;
     if (ldns_pkt_cd(pkt))
