@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2025 OARC, Inc.
+ * Copyright (c) 2016-2026 OARC, Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -43,8 +43,8 @@ hashtbl* hash_create(unsigned int N, hashkey_func hasher, hashkeycmp_func cmp, h
     hashtbl* new;
 
     assert(N);
-    assert(hasher);
-    assert(cmp);
+    assert(hasher != NULL);
+    assert(cmp != NULL);
 
     if ((new = calloc(1, sizeof(hashtbl)))) {
         new->modulus  = N;
