@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2025 OARC, Inc.
+ * Copyright (c) 2018-2026 OARC, Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -126,7 +126,7 @@ tcpstate_ptr tcpstate_new(iaddr from, iaddr to, unsigned sport, unsigned dport)
 {
     if (!_hash) {
         _hash = hash_create(65535, (hashkey_func)tcpstate_hash, (hashkeycmp_func)tcpstate_cmp, 0);
-        assert(_hash);
+        assert(_hash != NULL);
     }
     tcpstate_ptr tcpstate = calloc(1, sizeof *tcpstate);
     if (tcpstate == NULL) {
